pub struct FlowUpdateService { /* private fields */ }Implementations
Sourceimpl FlowUpdateService
impl FlowUpdateService
Sourcepub async fn from_url(
aquila_url: String,
definition_path: &str,
aquila_token: String,
) -> Self
pub async fn from_url( aquila_url: String, definition_path: &str, aquila_token: String, ) -> Self
Create a new FlowUpdateService instance from an Aquila URL and a definition path.
This reads the definition files from the given path as modules and initializes the service with those module definitions.
pub fn with_definition_source(self, source: String) -> Self
pub async fn send(&mut self)
pub async fn send_with_status(&mut self) -> bool