FlowUpdateService

Struct FlowUpdateService 

pub struct FlowUpdateService { /* private fields */ }

Implementations

Source

impl FlowUpdateService

pub async fn from_url( aquila_url: String, definition_path: &str, aquila_token: String, ) -> Self

Create a new FlowUpdateService instance from an Aquila URL and a definition path.

This will read the definition files from the given path and initialize the service with the data types, runtime function definitions, function definitions, and flow types.

pub fn with_flow_types(self, flow_types: Vec<FlowType>) -> Self

pub fn with_data_types(self, data_types: Vec<DataType>) -> Self

pub fn with_runtime_functions( self, runtime_functions: Vec<RuntimeFunctionDefinition>, ) -> Self

pub fn with_functions(self, functions: Vec<FunctionDefinition>) -> Self

pub async fn send(&self)

pub async fn send_with_status(&self) -> bool