pub struct FlowUpdateService { /* private fields */ }Implementations
Sourceimpl FlowUpdateService
impl FlowUpdateService
Sourcepub async fn from_url(aquila_url: String, definition_path: &str) -> Self
pub async fn from_url(aquila_url: String, definition_path: &str) -> Self
Create a new FlowUpdateService instance from an Aquila URL and a definition path.
This will read the definition files from the given path and initialize the service with the data types, runtime definitions, and flow types.
pub fn with_flow_types(self, flow_types: Vec<FlowType>) -> Self
pub fn with_data_types(self, data_types: Vec<DataType>) -> Self
pub fn with_runtime_definitions( self, runtime_definitions: Vec<RuntimeFunctionDefinition>, ) -> Self
pub async fn send(&self)